@@ -42,11 +42,8 @@ class KCMultiDialog;
 
 class QTimer;
 
-namespace Akregator
-{
-
-namespace Backend
-{
+namespace Akregator {
+namespace Backend {
 class Storage;
 }
 
@@ -90,7 +87,7 @@ public:
         Opens feedlist
         @param url URL to feedlist
         */
-    bool openUrl(const QUrl &url) Q_DECL_OVERRIDE;
+    bool openUrl(const QUrl &url) override;
 
     /** Opens standard feedlist */
     void openStandardFeedList();
@@ -163,7 +160,7 @@ private:
     void loadPlugins(const QString &type);
 
     /** This must be implemented by each part */
-    bool openFile() Q_DECL_OVERRIDE;
+    bool openFile() override;
 
     void importFile(const QUrl &url);
 
@@ -223,7 +220,7 @@ private: // attributes
     /** did we backup the feed list already? */
     bool m_backedUpList;
     Akregator::AkregatorCentralWidget *mCentralWidget;
-    QPointer<MainWidget>m_mainWidget;
+    QPointer<MainWidget> m_mainWidget;
     Backend::Storage *m_storage;
     ActionManagerImpl *m_actionManager;
     KCMultiDialog *m_dialog;
@@ -235,7 +232,6 @@ private: // attributes
     QVector<AddFeedRequest> m_requests;
     KSharedConfig::Ptr mConfig;
 };
-
 } // namespace Akregator
 
 #endif // AKREGATOR_PART_H
