@@ -64,10 +64,10 @@
 using namespace Akregator;
 
 ArticleViewerWebEngine::ArticleViewerWebEngine(KActionCollection *ac, QWidget *parent)
-    : WebEngineViewer::WebEngineView(parent),
-      mActionCollection(ac),
-      mLastButtonClicked(LeftButton),
-      mViewerPluginToolManager(nullptr)
+    : WebEngineViewer::WebEngineView(parent)
+    , mActionCollection(ac)
+    , mLastButtonClicked(LeftButton)
+    , mViewerPluginToolManager(nullptr)
 {
     mNetworkAccessManager = new WebEngineViewer::InterceptorManager(this, ac, this);
     QWebEngineProfile *profile = new QWebEngineProfile(this);
@@ -93,27 +93,22 @@ ArticleViewerWebEngine::ArticleViewerWebEngine(KActionCollection *ac, QWidget *p
     mWebShortcutMenuManager = new KIO::KUriFilterSearchProviderActions(this);
     mShareServiceManager = new PimCommon::ShareServiceUrlManager(this);
     connect(mShareServiceManager, &PimCommon::ShareServiceUrlManager::serviceUrlSelected, this, &ArticleViewerWebEngine::slotServiceUrlSelected);
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     connect(page(), &QWebEnginePage::audioMutedChanged,
             this, &ArticleViewerWebEngine::slotWebPageMutedOrAudibleChanged);
     connect(page(), &QWebEnginePage::recentlyAudibleChanged,
             this, &ArticleViewerWebEngine::slotWebPageMutedOrAudibleChanged);
-#endif
-
-    connect(WebEngineViewer::LocalDataBaseManager::self(), &WebEngineViewer::LocalDataBaseManager::checkUrlFinished, this, &ArticleViewerWebEngine::slotCheckedUrlFinished);
 
+    connect(phishingDatabase(), &WebEngineViewer::LocalDataBaseManager::checkUrlFinished,
+            this, &ArticleViewerWebEngine::slotCheckedUrlFinished);
 }
 
 ArticleViewerWebEngine::~ArticleViewerWebEngine()
 {
-
 }
 
 void ArticleViewerWebEngine::slotWebPageMutedOrAudibleChanged()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     Q_EMIT webPageMutedOrAudibleChanged(page()->isAudioMuted(), page()->recentlyAudible());
-#endif
 }
 
 QVariantHash ArticleViewerWebEngine::introductionData() const
@@ -148,6 +143,9 @@ void ArticleViewerWebEngine::paintAboutScreen(const QString &templateName, const
 
 void ArticleViewerWebEngine::slotServiceUrlSelected(PimCommon::ShareServiceUrlManager::ServiceType type)
 {
+    if (mCurrentUrl.isEmpty()) {
+        return;
+    }
     const QUrl url = mShareServiceManager->generateServiceUrl(mCurrentUrl.url(), QString(), type);
     mShareServiceManager->openUrl(url);
 }
@@ -175,11 +173,7 @@ void ArticleViewerWebEngine::slotCopyImageLocationInFrame()
 
 void ArticleViewerWebEngine::slotMute(bool mute)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     page()->setAudioMuted(mute);
-#else
-    Q_UNUSED(mute);
-#endif
 }
 
 void ArticleViewerWebEngine::slotCopyLinkAddress()
@@ -257,14 +251,12 @@ void ArticleViewerWebEngine::slotWebHitFinished(const WebEngineViewer::WebHitTes
         popup.addSeparator();
         popup.addActions(viewerPluginActionList(MessageViewer::ViewerPluginInterface::NeedSelection));
     }
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     popup.addSeparator();
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("viewer_print")));
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("viewer_printpreview")));
     popup.addSeparator();
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("tab_mute")));
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("tab_unmute")));
-#endif
     popup.addSeparator();
     popup.addAction(ActionManager::getInstance()->action(QStringLiteral("find_in_messages")));
     if (KPIMTextEdit::TextToSpeech::self()->isReady()) {
@@ -351,9 +343,7 @@ void ArticleViewerWebEngine::setArticleAction(ArticleViewerWebEngine::ArticleAct
 
 void ArticleViewerWebEngine::restoreCurrentPosition()
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 7, 0)
     mPageEngine->runJavaScript(WebEngineViewer::WebEngineScript::scrollToRelativePosition(relativePosition()));
-#endif
 }
 
 void ArticleViewerWebEngine::forwardMouseReleaseEvent(QMouseEvent *event)
@@ -397,7 +387,6 @@ void ArticleViewerWebEngine::slotCheckedUrlFinished(const QUrl &url, WebEngineVi
         break;
     }
     openSafeUrl(url);
-
 }
 
 void ArticleViewerWebEngine::slotLinkClicked(const QUrl &url)
@@ -406,7 +395,7 @@ void ArticleViewerWebEngine::slotLinkClicked(const QUrl &url)
         return;
     }
     if (Settings::checkPhishingUrl()) {
-        WebEngineViewer::LocalDataBaseManager::self()->checkUrl(url);
+        phishingDatabase()->checkUrl(url);
     } else {
         openSafeUrl(url);
     }
