@@ -21,8 +21,7 @@
 #define ARTICLEVIEWERWEBENGINEPAGE_H
 
 #include <WebEngineViewer/WebEnginePage>
-namespace Akregator
-{
+namespace Akregator {
 class ArticleViewerWebEnginePage : public WebEngineViewer::WebEnginePage
 {
     Q_OBJECT
@@ -34,7 +33,7 @@ Q_SIGNALS:
     void urlClicked(const QUrl &url);
 
 protected:
-    bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame) Q_DECL_OVERRIDE;
+    bool acceptNavigationRequest(const QUrl &url, NavigationType type, bool isMainFrame) override;
 
 private:
     void slotFeaturePermissionRequested(const QUrl &url, QWebEnginePage::Feature feature);
